package main

import "math/rand"


func IntegraTrap(f func(float64) float64, a float64, b float64, n int) float64 {
	delta := (b-a) / float64(n)  // Base di ciascun trapezio
	somma := 0.0
	for i := 0; i < n; i++ {
		// Considero il trapezio che va da a+i*delta ad a+(i+1)*delta
		start := a + float64(i) * delta
		end := a + float64(i+1) * delta
		areaTrapezio := (f(start) + f(end)) * delta / 2.0
		somma += areaTrapezio
	}
	return somma
}

/* la funzione f, nell'intervallo [a,b], è tutta compresa fra -M e +M; n è il numero di spari */
func IntegraMonteCarlo(f func(float64) float64, a float64, b float64, n int, M float64) float64 {
	// Porzione sopra l'asse x
	sotto := 0
	for i := 0; i < n; i++ {
		x := a + rand.Float64() * (b-a)
		y := rand.Float64() * M
		if y < f(x) {  // Il punto (x,y) sta sotto la curva
			sotto++
		}
	}
	areaPos := M * (b-a) * float64(sotto) / float64(n)
	// Porzione sotto l'asse x
	sopra := 0
	for i := 0; i < n; i++ {
		x := a + rand.Float64() * (b-a)
		y := - rand.Float64() * M
		if y > f(x) {  // Il punto (x,y) sta sopra la curva
			sopra++
		}
	}
	areaNeg := M * (b-a) * float64(sopra) / float64(n)
	return areaPos - areaNeg
}
