package main

import "testing"
import "math"

type EsempioDiIntegrazione struct {
	f func(float64) float64
	a,b float64
	primitiva func(float64) float64
}

var esempi = []EsempioDiIntegrazione{
	EsempioDiIntegrazione{math.Sin, 3, 7, func (x float64) float64 {return -math.Cos(x)}},
	EsempioDiIntegrazione{func (x float64) float64 {return x*x}, -3, 3, func (x float64) float64 {return x*x*x/3.0}},
}

func TestIntegraTrap(t *testing.T) {
	for _, esempio := range esempi {
		actual := IntegraTrap(esempio.f, esempio.a, esempio.b, 10000)
		expected := esempio.primitiva(esempio.b) - esempio.primitiva(esempio.a)
		if math.Abs(actual - expected) > 1E-5 {
			t.Error("Integrale atteso: ", expected, " ottenuto: ", actual)
		}
	}
}

func TestIntegraMonteCarlo(t *testing.T) {
	for _, esempio := range esempi {
		actual := IntegraMonteCarlo(esempio.f, esempio.a, esempio.b, 10000000, 10)
		expected := esempio.primitiva(esempio.b) - esempio.primitiva(esempio.a)
		if math.Abs(actual - expected) > 1E-1 {
			t.Error("Integrale atteso: ", expected, " ottenuto: ", actual)
		}
	}
}